The base element allows authors to specify the document base URL for the purposes of parsing
URLs, and the name of the default navigable for the purposes of following hyperlinks. The
element does not represent any content beyond this information.
The blockquote element represents a section that is quoted from another source.
Content inside a blockquote must be quoted from another source, whose address, if it has one,
may be cited in the Blockquote::cite attribute.
The canvas element provides scripts with a resolution-dependent bitmap canvas, which can be
used for rendering graphs, game graphics, art, or other visual images on the fly. The contents
of the canvas element, if any, are the element’s fallback content.
If a col element has a parent and that is a super::colgroup::Colgroup element that itself
has a parent that is a super::table element, then the col element represents one or more
columns in the column group represented by that super::colgroup::Colgroup.
The colgroup element represents a group of one or more columns in the super::table that is
its parent, if it has a parent and that is a super::table element.
The data element represents a group of one or more columns in the super::table that is its
parent, if it has a parent and that is a super::table element.
The fieldset element represents a set of form controls (or other content) grouped together,
optionally with a caption. The caption is given by the first super::legend element that is a
child of the super::fieldset element, if any. The remainder of the descendants form the group.
The form element represents a hyperlink that can be manipulated through a collection of
form-associated elements, some of which can represent editable values that can be submitted to a
server for processing.
The map element, in conjunction with an super::img element and any super::area element
descendants, defines an image map. The element represents its children.
The meter element represents a scalar measurement within a known range, or a fractional value;
for example disk usage, the relevance of a query result, or the fraction of a voting population
to have selected a particular candidate.
The object element can represent an external resource, which, depending on the type of the
resource, will either be treated as an image or as a child navigable.
The ol element represents a list of items, where the items have been intentionally ordered, such
that changing the order would change the meaning of the document.
The progress element represents the completion progress of a task. The progress is either
indeterminate, indicating that progress is being made but that it is not clear how much more
work remains to be done before the task is complete (e.g. because the task is waiting for a
remote host to respond), or the progress is a number in the range zero to a maximum, giving the
fraction of work that has so far been completed.
The slot element defines a slot. It is typically used in a shadow tree. A slot element
represents its assigned nodes, if any, and its contents otherwise.
The style element allows authors to embed CSS style sheets in their documents. The style
element is one of several inputs to the styling processing model. The element does not represent
content for the user.
The textarea element represents a multiline plain text edit control for the element’s raw
value. The contents of the control represent the control’s default value.
The track element allows authors to specify explicit external timed text tracks for media
(super::audio, super::video) elements. It does not represent anything on its own.
The abbr element represents an abbreviation or acronym, optionally with its expansion. The Global::title attribute may be used to provide an expansion of the abbreviation. The attribute, if specified, must contain an expansion of the abbreviation, and nothing else.
The address element represents the contact information for its nearest h::article or h::body element ancestor. If that is the h::body element, then the contact information applies to the document as a whole.
The article element represents a complete, or self-contained, composition in a document, page, application, or site and that is, in principle, independently distributable or reusable, e.g. in syndication. This could be a forum post, a magazine or newspaper article, a blog entry, a user-submitted comment, an interactive widget or gadget, or any other independent item of content.
The aside element represents a section of a page that consists of content that is tangentially related to the content around the aside element, and which could be considered separate from that content. Such sections are often represented as sidebars in printed typography.
The b element represents a span of text to which attention is being drawn for utilitarian purposes without conveying any extra importance and with no implication of an alternate voice or mood, such as key words in a document abstract, product names in a review, actionable words in interactive text-driven software, or an article lede.
The base element allows authors to specify the document base URL for the purposes of parsing
URLs, and the name of the default navigable for the purposes of following hyperlinks. The
element does not represent any content beyond this information.
The bdi element represents a span of text that is to be isolated from its surroundings for the purposes of bidirectional text formatting.
The Global::dir attribute defaults to cabin::html::elements::global::Dir::Auto on this element (it never inherits from the parent element like with other elements).
The bdo element represents explicit text directionality formatting control for its children. It allows authors to override the Unicode bidirectional algorithm by explicitly specifying a direction override.
Authors must specify the Global::dir attribute on this element, with the value cabin::html::elements::global::Dir::Ltr to specify a left-to-right override and with the value cabin::html::elements::global::Dir::Rtl to specify a right-to-left override. The cabin::html::elements::global::Dir::Auto value must not be specified.
The blockquote element represents a section that is quoted from another source.
Content inside a blockquote must be quoted from another source, whose address, if it has one,
may be cited in the Blockquote::cite attribute.
The canvas element provides scripts with a resolution-dependent bitmap canvas, which can be
used for rendering graphs, game graphics, art, or other visual images on the fly. The contents
of the canvas element, if any, are the element’s fallback content.
If a col element has a parent and that is a super::colgroup::Colgroup element that itself
has a parent that is a super::table element, then the col element represents one or more
columns in the column group represented by that super::colgroup::Colgroup.
The colgroup element represents a group of one or more columns in the super::table that is
its parent, if it has a parent and that is a super::table element.
The data element represents a group of one or more columns in the super::table that is its
parent, if it has a parent and that is a super::table element.
The datalist element represents a set of h::option elements that represent predefined options for other controls. In the rendering, the datalist element represents nothing and it, along with its children, should be hidden.
The dfn element represents the defining instance of a term. The paragraph, description list group, or section that is the nearest ancestor of the dfn element must also contain the definition(s) for the term given by the dfn element.
The fieldset element represents a set of form controls (or other content) grouped together,
optionally with a caption. The caption is given by the first super::legend element that is a
child of the super::fieldset element, if any. The remainder of the descendants form the group.
The figure element represents some flow content, optionally with a caption, that is self-contained (like a complete sentence) and is typically referenced as a single unit from the main flow of the document.
The footer element represents a footer for its nearest ancestor sectioning content element, or for the body element if there is no such ancestor. A footer typically contains information about its section such as who wrote it, links to related documents, copyright data, and the like.
The form element represents a hyperlink that can be manipulated through a collection of
form-associated elements, some of which can represent editable values that can be submitted to a
server for processing.
The hgroup element represents a heading and related content. The element may be used to group an h::h1–h::h6 element with one or more h::p elements containing content representing a subheading, alternative title, or tagline.
The i element represents a span of text in an alternate voice or mood, or otherwise offset from the normal prose in a manner indicating a different quality of text, such as a taxonomic designation, a technical term, an idiomatic phrase from another language, transliteration, a thought, or a ship name in Western texts.
The li element represents a list item. If its parent element is an h::ol, h::ul, or h::menu element, then the element is an item of the parent element’s list, as defined for those elements. Otherwise, the list item has no defined list-related relationship to any other li element.
The map element, in conjunction with an super::img element and any super::area element
descendants, defines an image map. The element represents its children.
The mark element represents a run of text in one document marked or highlighted for reference purposes, due to its relevance in another context. When used in a quotation or other block of text referred to from the prose, it indicates a highlight that was not originally present but which has been added to bring the reader’s attention to a part of the text that might not have been considered important by the original author when the block was originally written, but which is now under previously unexpected scrutiny. When used in the main prose of a document, it indicates a part of the document that has been highlighted due to its likely relevance to the user’s current activity.
The menu element represents a toolbar consisting of its contents, in the form of an unordered list of items (represented by h::li elements), each of which represents a command that the user can perform or activate.
The meter element represents a scalar measurement within a known range, or a fractional value;
for example disk usage, the relevance of a query result, or the fraction of a voting population
to have selected a particular candidate.
The noscript element represents nothing if scripting is enabled, and represents its children if scripting is disabled. It is used to present different markup to user agents that support scripting and those that don’t support scripting, by affecting how the document is parsed.
The object element can represent an external resource, which, depending on the type of the
resource, will either be treated as an image or as a child navigable.
The ol element represents a list of items, where the items have been intentionally ordered, such
that changing the order would change the meaning of the document.
The picture element is a container which provides multiple sources to its contained h::img element to allow authors to declaratively control or give hints to the user agent about which image resource to use, based on the screen pixel density, viewport size, image format, and other factors. It represents its children.
The progress element represents the completion progress of a task. The progress is either
indeterminate, indicating that progress is being made but that it is not clear how much more
work remains to be done before the task is complete (e.g. because the task is waiting for a
remote host to respond), or the progress is a number in the range zero to a maximum, giving the
fraction of work that has so far been completed.
The rp element can be used to provide parentheses or other content around a h::ruby text component of a ruby annotation, to be shown by user agents that don’t support ruby annotations.
The rt element marks the ruby text component of a ruby annotation. When it is the child of a h::ruby element, it doesn’t represent anything itself, but the h::ruby element uses it as part of determining what it represents.
The ruby element allows one or more spans of phrasing content to be marked with ruby annotations. Ruby annotations are short runs of text presented alongside base text, primarily used in East Asian typography as a guide for pronunciation or to include other annotations. In Japanese, this form of typography is also known as furigana.
The search element represents a part of a document or application that contains a set of form controls or other content related to performing a search or filtering operation. This could be a search of the web site or application; a way of searching or filtering search results on the current web page; or a global or Internet-wide search function.
The section element represents a generic section of a document or application. A section, in this context, is a thematic grouping of content, typically with a heading.
The slot element defines a slot. It is typically used in a shadow tree. A slot element
represents its assigned nodes, if any, and its contents otherwise.
The source element allows authors to specify multiple alternative source sets for super::img
elements or multiple alternative media resources for media elements. It does not represent
anything on its own.
The style element allows authors to embed CSS style sheets in their documents. The style
element is one of several inputs to the styling processing model. The element does not represent
content for the user.
The tbody element represents a block of rows that consist of a body of data for the parent h::table element, if the tbody element has a parent and it is a table.
The textarea element represents a multiline plain text edit control for the element’s raw
value. The contents of the control represent the control’s default value.
The tfoot element represents the block of rows that consist of the column summaries (footers) for the parent h::table element, if the tfoot element has a parent and it is a table.
The thead element represents the block of rows that consist of the column labels (headers) and any ancillary non-header cells for the parent h::table element, if the thead element has a parent and it is a table.
The title element represents the document’s title or name. Authors should use titles that
identify their documents even when they are used out of context, for example in a user’s history
or bookmarks, or in search results. The document’s title is often different from its first
heading, since the first heading does not have to stand alone when taken out of context.
The track element allows authors to specify explicit external timed text tracks for media
(super::audio, super::video) elements. It does not represent anything on its own.
The u element represents a span of text with an unarticulated, though explicitly rendered, non-textual annotation, such as labeling the text as being a proper name in Chinese text (a Chinese proper name mark), or labeling the text as being misspelt.
The ul element represents a list of items, where the order of the items is not important — that is, where changing the order would not materially change the meaning of the document.
The var element represents a variable. This could be an actual variable in a mathematical expression or programming context, an identifier representing a constant, a symbol identifying a physical quantity, a function parameter, or just be a term used as a placeholder in prose.