pub struct AriaPosInset(pub u32);Expand description
Defines an element’s number or position in the current set of listitems or treeitems. Not required if all elements in the set are present in the DOM. See related aria-setsize.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Attributes for AriaPosInset
impl Attributes for AriaPosInset
Sourceimpl Clone for AriaPosInset
impl Clone for AriaPosInset
Sourcefn clone(&self) -> AriaPosInset
fn clone(&self) -> AriaPosInset
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AriaPosInset
impl Debug for AriaPosInset
Sourceimpl Hash for AriaPosInset
impl Hash for AriaPosInset
Sourceimpl Ord for AriaPosInset
impl Ord for AriaPosInset
Sourcefn cmp(&self, other: &AriaPosInset) -> Ordering
fn cmp(&self, other: &AriaPosInset) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AriaPosInset
impl PartialEq for AriaPosInset
Sourceimpl PartialOrd for AriaPosInset
impl PartialOrd for AriaPosInset
impl Eq for AriaPosInset
impl StructuralPartialEq for AriaPosInset