pub struct AriaRowIndex(pub u32);Expand description
Defines an element’s row index or position with respect to the total number of rows within a table, grid, or treegrid. See related aria-rowindextext, aria-rowcount, and aria-rowspan.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Attributes for AriaRowIndex
impl Attributes for AriaRowIndex
Sourceimpl Clone for AriaRowIndex
impl Clone for AriaRowIndex
Sourcefn clone(&self) -> AriaRowIndex
fn clone(&self) -> AriaRowIndex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AriaRowIndex
impl Debug for AriaRowIndex
Sourceimpl Hash for AriaRowIndex
impl Hash for AriaRowIndex
Sourceimpl Ord for AriaRowIndex
impl Ord for AriaRowIndex
Sourcefn cmp(&self, other: &AriaRowIndex) -> Ordering
fn cmp(&self, other: &AriaRowIndex) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AriaRowIndex
impl PartialEq for AriaRowIndex
Sourceimpl PartialOrd for AriaRowIndex
impl PartialOrd for AriaRowIndex
impl Eq for AriaRowIndex
impl StructuralPartialEq for AriaRowIndex