pub struct AriaRowSpan(pub u32);Expand description
Defines the number of rows spanned by a cell or gridcell within a table, grid, or treegrid. See related aria-rowindex and aria-colspan.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Attributes for AriaRowSpan
impl Attributes for AriaRowSpan
Sourceimpl Clone for AriaRowSpan
impl Clone for AriaRowSpan
Sourcefn clone(&self) -> AriaRowSpan
fn clone(&self) -> AriaRowSpan
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AriaRowSpan
impl Debug for AriaRowSpan
Sourceimpl Hash for AriaRowSpan
impl Hash for AriaRowSpan
Sourceimpl Ord for AriaRowSpan
impl Ord for AriaRowSpan
Sourcefn cmp(&self, other: &AriaRowSpan) -> Ordering
fn cmp(&self, other: &AriaRowSpan) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AriaRowSpan
impl PartialEq for AriaRowSpan
Sourceimpl PartialOrd for AriaRowSpan
impl PartialOrd for AriaRowSpan
impl Eq for AriaRowSpan
impl StructuralPartialEq for AriaRowSpan