Module data

Module data 

Modules

marker

Traits

Data
The data element represents a group of one or more columns in the super::table that is its parent, if it has a parent and that is a super::table element.

Functions

data
The data element represents a group of one or more columns in the super::table that is its parent, if it has a parent and that is a super::table element.