pub trait Meter: WithAttribute {
// Provided methods
fn value(self, value: impl Into<Cow<'static, str>>) -> Self::Output<Value> { ... }
fn min(self, min: impl Into<Cow<'static, str>>) -> Self::Output<Min> { ... }
fn max(self, max: impl Into<Cow<'static, str>>) -> Self::Output<Max> { ... }
fn low(self, low: impl Into<Cow<'static, str>>) -> Self::Output<Low> { ... }
fn high(self, high: impl Into<Cow<'static, str>>) -> Self::Output<High> { ... }
fn optimum(
self,
optimum: impl Into<Cow<'static, str>>,
) -> Self::Output<Optimum> { ... }
}Expand description
The meter element represents a scalar measurement within a known range, or a fractional value;
for example disk usage, the relevance of a query result, or the fraction of a voting population
to have selected a particular candidate.
Provided Methods
Sourcefn value(self, value: impl Into<Cow<'static, str>>) -> Self::Output<Value>
fn value(self, value: impl Into<Cow<'static, str>>) -> Self::Output<Value>
Current value of the element.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.