Ol

Trait Ol 

pub trait Ol: WithAttribute {
    // Provided methods
    fn reversed(self, reversed: bool) -> Self::Output<Reversed> { ... }
    fn start(self, start: u32) -> Self::Output<Start> { ... }
    fn type(self, type: Type) -> Self::Output<Type> { ... }
    fn type_decimal(self) -> Self::Output<Type> { ... }
    fn type_lower_alpha(self) -> Self::Output<Type> { ... }
    fn type_upper_alpha(self) -> Self::Output<Type> { ... }
    fn type_lower_roman(self) -> Self::Output<Type> { ... }
    fn type_upper_roman(self) -> Self::Output<Type> { ... }
}
The ol element represents a list of items, where the items have been intentionally ordered, such that changing the order would change the meaning of the document.

Provided Methods

fn reversed(self, reversed: bool) -> Self::Output<Reversed>

Number the list backwards.

fn start(self, start: u32) -> Self::Output<Start>

Starting value of the list.

fn type(self, type: Type) -> Self::Output<Type>

Kind of list marker.

fn type_decimal(self) -> Self::Output<Type>

fn type_lower_alpha(self) -> Self::Output<Type>

fn type_upper_alpha(self) -> Self::Output<Type>

fn type_lower_roman(self) -> Self::Output<Type>

fn type_upper_roman(self) -> Self::Output<Type>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<A: Attributes, V: 'static> Ol for Html<Ol, A, V>