Module select

Module select 

Modules

marker

Traits

Select
The select element represents a control for selecting amongst a set of super::options.

Functions

select
The select element represents a control for selecting amongst a set of super::options.