Module time

Module time 

Modules

marker

Structs

Datetime
Machine-readable datetime/date/time of the element’s contents.

Traits

Time
The time element represents a datetime, in machine-readable form as the datetime attribute, and in human-readable form as its content.

Functions

time
The time element represents a datetime, in machine-readable form as the datetime attribute, and in human-readable form as its content.