menu

Function menu 

pub fn menu(content: impl View) -> Html<Menu, (), impl View>
The menu element represents a toolbar consisting of its contents, in the form of an unordered list of items (represented by h::li elements), each of which represents a command that the user can perform or activate.