pre

Function pre 

pub fn pre(content: impl View) -> Html<Pre, (), impl View>
The pre element represents a block of preformatted text, in which structure is represented by typographic conventions rather than by elements.