summary

Function summary 

pub fn summary(content: impl View) -> Html<Summary, (), impl View>
The summary element represents a summary, caption, or legend for the rest of the contents of the summary element’s parent h::details element, if any.