Progress

Trait Progress 

pub trait Progress: WithAttribute {
    // Provided methods
    fn value(self, value: impl Into<Cow<'static, str>>) -> Self::Output<Value> { ... }
    fn max(self, max: impl Into<Cow<'static, str>>) -> Self::Output<Max> { ... }
}
The progress element represents the completion progress of a task. The progress is either indeterminate, indicating that progress is being made but that it is not clear how much more work remains to be done before the task is complete (e.g. because the task is waiting for a remote host to respond), or the progress is a number in the range zero to a maximum, giving the fraction of work that has so far been completed.

Provided Methods

fn value(self, value: impl Into<Cow<'static, str>>) -> Self::Output<Value>

Current value of the element.

fn max(self, max: impl Into<Cow<'static, str>>) -> Self::Output<Max>

Upper bound of range.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<A: Attributes, V: 'static> Progress for Html<Progress, A, V>