pub enum Kind {
Subtitles,
Captions,
Descriptions,
Chapters,
Metadata,
}Expand description
Data type of an input element.
Variants
Subtitles
Transcription or translation of the dialogue, suitable for when the sound is available but not understood. Overlaid on the video.
Captions
Transcription or translation of the dialogue, sound effects, relevant musical cues, and other relevant audio information, suitable for when sound is unavailable or not clearly audible. Overlaid on the video; labeled as appropriate for the hard-of-hearing.
Descriptions
Textual descriptions of the video component of the media resource, intended for audio synthesis when the visual component is obscured, unavailable, or not usable. Synthesized as audio.
Chapters
Track intended for use from script. Not displayed by the user agent.
Metadata
Track intended for use from script. Not displayed by the user agent.