Global

Trait Global 

pub trait Global: WithAttribute {
Show 31 methods // Provided methods fn access_key( self, access_key: impl Into<Cow<'static, str>>, ) -> Self::Output<AccessKey> { ... } fn auto_capitalize( self, auto_capitalize: AutoCapitalize, ) -> Self::Output<AutoCapitalize> { ... } fn auto_focus(self) -> Self::Output<AutoFocus> { ... } fn with_auto_focus(self, auto_focus: bool) -> Self::Output<AutoFocus> { ... } fn content_editable(self) -> Self::Output<ContentEditable> { ... } fn with_content_editable( self, content_editable: bool, ) -> Self::Output<ContentEditable> { ... } fn dir(self, dir: Dir) -> Self::Output<Dir> { ... } fn draggable(self) -> Self::Output<Draggable> { ... } fn with_draggable(self, draggable: bool) -> Self::Output<Draggable> { ... } fn enter_key_hint( self, enter_key_hint: EnterKeyHint, ) -> Self::Output<EnterKeyHint> { ... } fn hidden(self, hidden: Hidden) -> Self::Output<Hidden> { ... } fn inert(self) -> Self::Output<Inert> { ... } fn with_inert(self, inert: bool) -> Self::Output<Inert> { ... } fn input_mode(self, input_mode: InputMode) -> Self::Output<InputMode> { ... } fn is(self, is: impl Into<Cow<'static, str>>) -> Self::Output<Is> { ... } fn item_id( self, item_id: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemId> { ... } fn item_prop( self, item_prop: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemProp> { ... } fn item_ref( self, item_ref: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemRef> { ... } fn item_scope(self) -> Self::Output<ItemScope> { ... } fn with_item_scope(self, item_scope: bool) -> Self::Output<ItemScope> { ... } fn item_type( self, item_type: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemType> { ... } fn lang(self, lang: impl Into<Cow<'static, str>>) -> Self::Output<Lang> { ... } fn nonce(self, nonce: impl Into<Cow<'static, str>>) -> Self::Output<Nonce> { ... } fn popover(self) -> Self::Output<Popover> { ... } fn with_popover(self, popover: bool) -> Self::Output<Popover> { ... } fn slot(self, slot: impl Into<Cow<'static, str>>) -> Self::Output<Slot> { ... } fn spellcheck(self, spellcheck: bool) -> Self::Output<Spellcheck> { ... } fn style(self, style: impl Into<Cow<'static, str>>) -> Self::Output<Style> { ... } fn tab_index(self, tab_index: TabIndex) -> Self::Output<TabIndex> { ... } fn title(self, title: impl Into<Cow<'static, str>>) -> Self::Output<Title> { ... } fn translate(self, translate: bool) -> Self::Output<Translate> { ... }
}

Provided Methods

fn access_key( self, access_key: impl Into<Cow<'static, str>>, ) -> Self::Output<AccessKey>

Used by the user agent as a guide for creating a keyboard shortcut that activates or focuses the element.

fn auto_capitalize( self, auto_capitalize: AutoCapitalize, ) -> Self::Output<AutoCapitalize>

Hints the user-agent of how to automatically capitalize input (from non-physical

fn auto_focus(self) -> Self::Output<AutoFocus>

Indicate that the element is to be focused as soon as the page is loaded.

fn with_auto_focus(self, auto_focus: bool) -> Self::Output<AutoFocus>

Indicate that the element is to be focused as soon as the page is loaded.

fn content_editable(self) -> Self::Output<ContentEditable>

Indicating whether the element should be editable by the user.

fn with_content_editable( self, content_editable: bool, ) -> Self::Output<ContentEditable>

Indicating whether the element should be editable by the user.

fn dir(self, dir: Dir) -> Self::Output<Dir>

The element’s text directionality.

fn draggable(self) -> Self::Output<Draggable>

Indicate whether the element can be dragged.

fn with_draggable(self, draggable: bool) -> Self::Output<Draggable>

Indicate whether the element can be dragged.

fn enter_key_hint( self, enter_key_hint: EnterKeyHint, ) -> Self::Output<EnterKeyHint>

Indicate the action label (or icon) to present for the enter key on virtual keyboards.

fn hidden(self, hidden: Hidden) -> Self::Output<Hidden>

Hide the element (visually and from screen-readers).

fn inert(self) -> Self::Output<Inert>

Mark the element as not presently accessible (e.g. when overlayed by a loading state).

fn with_inert(self, inert: bool) -> Self::Output<Inert>

Mark the element as not presently accessible (e.g. when overlayed by a loading state).

fn input_mode(self, input_mode: InputMode) -> Self::Output<InputMode>

Hint an input mechanism that would be most helpful for users entering content.

fn is(self, is: impl Into<Cow<'static, str>>) -> Self::Output<Is>

The element should behave like the defined custom element.

fn item_id(self, item_id: impl Into<Cow<'static, str>>) -> Self::Output<ItemId>

Unique, global identifier of the item (item_scope and item_type must also be defined).

fn item_prop( self, item_prop: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemProp>

A microdata name-value pair (this is the name – either a string or URL; the element’s content is the value).

fn item_ref( self, item_ref: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemRef>

List of element IDs elsewehre in the document with additional properties.

fn item_scope(self) -> Self::Output<ItemScope>

Create a new item by scoping the the descendent properties together (item_type must also be defined).

fn with_item_scope(self, item_scope: bool) -> Self::Output<ItemScope>

Create a new item by scoping the the descendent properties together (item_type must also be defined).

fn item_type( self, item_type: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemType>

URL of the vocabulary that will be used to define item properties in the data structure.

fn lang(self, lang: impl Into<Cow<'static, str>>) -> Self::Output<Lang>

Primary language of the element’s contents.

fn nonce(self, nonce: impl Into<Cow<'static, str>>) -> Self::Output<Nonce>

Cryptographic nonce (“number used once”) which can be used by Content Security Policy to determine whether or not a given fetch will be allowed to proceed.

fn popover(self) -> Self::Output<Popover>

Don’t render the element until it becomes shown, at which point it will be rendered on top of other page content.

fn with_popover(self, popover: bool) -> Self::Output<Popover>

Don’t render the element until it becomes shown, at which point it will be rendered on top of other page content.

fn slot(self, slot: impl Into<Cow<'static, str>>) -> Self::Output<Slot>

The slot name this element is assigned to.

fn spellcheck(self, spellcheck: bool) -> Self::Output<Spellcheck>

Explicitly enable or disable spelling and grammar checking for the element’s contents.

fn style(self, style: impl Into<Cow<'static, str>>) -> Self::Output<Style>

Inline CSS.

fn tab_index(self, tab_index: TabIndex) -> Self::Output<TabIndex>

Specifify how and in which order the element can be focused.

fn title(self, title: impl Into<Cow<'static, str>>) -> Self::Output<Title>

Advisory information for the element, such as would be appropriate for a tooltip.

fn translate(self, translate: bool) -> Self::Output<Translate>

Indicate that the contents of this element should not be translated when the page is localized.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<A: Attributes, V: 'static> Global for UpdateView<Html<Body, A, V>>

Source

impl<A: Attributes, V: 'static> Global for UpdateView<Html<Head, A, V>>

Source

impl<A: Attributes, V: 'static> Global for UpdateView<Html<Html, A, V>>

Source

impl<A: Attributes, V: 'static> Global for Html<Anchor, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Area, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Audio, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Base, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Blockquote, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Button, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Canvas, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Col, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Colgroup, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Data, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Del, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Details, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Dialog, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Abbr, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Address, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Article, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Aside, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<B, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Bdi, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Bdo, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Br, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Caption, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Cite, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Code, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Datalist, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Dd, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Dfn, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Div, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Dl, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Dt, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Em, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<FigCaption, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Figure, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Footer, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<H1, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<H2, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<H3, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<H4, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<H5, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<H6, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Header, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<HGroup, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Hr, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<I, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Kbd, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Leged, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Li, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Main, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Mark, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Menu, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Nav, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<NoScript, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<P, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Picture, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Pre, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Rp, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Rt, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Ruby, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<S, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Samp, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Search, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Section, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Small, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Span, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Strong, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Sub, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Summary, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Sup, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Table, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<TBody, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Template, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<TFoot, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<THead, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Title, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Tr, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<U, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Ul, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Var, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Wbr, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Embed, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Fieldset, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Form, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<IFrame, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Img, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Input, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Ins, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Label, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Link, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Map, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Meta, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Meter, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Object, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Ol, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<OptGroup, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<SelectOption, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Output, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Progress, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Q, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Script, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Select, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Slot, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Source, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Style, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Td, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Textarea, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Th, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Time, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Track, A, V>

Source

impl<A: Attributes, V: 'static> Global for Html<Video, A, V>