pub trait Col: WithAttribute {
// Provided method
fn span(self, width: u32) -> Self::Output<Span> { ... }
}Expand description
If a col element has a parent and that is a super::colgroup::Colgroup element that itself
has a parent that is a super::table element, then the col element represents one or more
columns in the column group represented by that super::colgroup::Colgroup.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.