Module script
Source - marker
- Async
- Execute script when available, without blocking while fetching.
- Defer
- Defer script execution.
- Integrity
- Integrity metadata used in Subresource Integrity checks.
- NoModule
- Whether to prevent execution in user agents that support module scripts.
- ScriptEscape
- Src
- Address of the resource.
- Script
- A
script element allows to include dynamic script and data blocks in their documents.
- script
- A
script element allows to include dynamic script and data blocks in their documents.