pub trait Track: WithAttribute {
// Provided methods
fn kind(self, kind: Kind) -> Self::Output<Kind> { ... }
fn kind_subtitles(self) -> Self::Output<Kind> { ... }
fn kind_captions(self) -> Self::Output<Kind> { ... }
fn kind_descriptions(self) -> Self::Output<Kind> { ... }
fn kind_chapters(self) -> Self::Output<Kind> { ... }
fn kind_metadata(self) -> Self::Output<Kind> { ... }
fn src(self, src: impl Into<Cow<'static, str>>) -> Self::Output<Src> { ... }
fn src_lang(
self,
src_lang: impl Into<Cow<'static, str>>,
) -> Self::Output<SrcLang> { ... }
fn label(self, value: impl Into<Cow<'static, str>>) -> Self::Output<Label> { ... }
fn default(self) -> Self::Output<Default> { ... }
fn with_default(self, default: bool) -> Self::Output<Default> { ... }
}Expand description
The track element allows authors to specify explicit external timed text tracks for media
(super::audio, super::video) elements. It does not represent anything on its own.
Provided Methods
fn kind_subtitles(self) -> Self::Output<Kind>
fn kind_captions(self) -> Self::Output<Kind>
fn kind_descriptions(self) -> Self::Output<Kind>
fn kind_chapters(self) -> Self::Output<Kind>
fn kind_metadata(self) -> Self::Output<Kind>
Sourcefn src_lang(
self,
src_lang: impl Into<Cow<'static, str>>,
) -> Self::Output<SrcLang>
fn src_lang( self, src_lang: impl Into<Cow<'static, str>>, ) -> Self::Output<SrcLang>
Language of the text track.
Sourcefn default(self) -> Self::Output<Default>
fn default(self) -> Self::Output<Default>
Enable the track if no other text track is more suitable.
Sourcefn with_default(self, default: bool) -> Self::Output<Default>
fn with_default(self, default: bool) -> Self::Output<Default>
Enable the track if no other text track is more suitable.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.