pub fn base() -> Html<Base, (), ()>Expand description
The base element allows authors to specify the document base URL for the purposes of parsing
URLs, and the name of the default navigable for the purposes of following hyperlinks. The
element does not represent any content beyond this information.