pub fn kbd(content: impl View) -> Html<Kbd, (), impl View>
The kbd element represents user input (typically keyboard input, although it may also be used to represent other input, such as voice commands).
kbd