pub fn rt(content: impl View) -> Html<Rt, (), impl View>
The rt element marks the ruby text component of a ruby annotation. When it is the child of a h::ruby element, it doesn’t represent anything itself, but the h::ruby element uses it as part of determining what it represents.
rt