pub trait Object: WithAttribute {
// Provided methods
fn data(self, data: impl Into<Cow<'static, str>>) -> Self::Output<Data> { ... }
fn type(self, type: impl Into<Cow<'static, str>>) -> Self::Output<Type> { ... }
fn name(self, name: impl Into<Cow<'static, str>>) -> Self::Output<Name> { ... }
fn form(self, form: impl Into<Cow<'static, str>>) -> Self::Output<Form> { ... }
fn width(self, width: u32) -> Self::Output<Width> { ... }
fn height(self, height: u32) -> Self::Output<Height> { ... }
}Expand description
The object element can represent an external resource, which, depending on the type of the
resource, will either be treated as an image or as a child navigable.
Provided Methods
Sourcefn data(self, data: impl Into<Cow<'static, str>>) -> Self::Output<Data>
fn data(self, data: impl Into<Cow<'static, str>>) -> Self::Output<Data>
Address of the resource.
Sourcefn type(self, type: impl Into<Cow<'static, str>>) -> Self::Output<Type>
fn type(self, type: impl Into<Cow<'static, str>>) -> Self::Output<Type>
Type of embedded resource.
Sourcefn name(self, name: impl Into<Cow<'static, str>>) -> Self::Output<Name>
fn name(self, name: impl Into<Cow<'static, str>>) -> Self::Output<Name>
Name of content navigable.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.