pub trait Textarea: WithAttribute {
Show 19 methods
// Provided methods
fn autocomplete(
self,
autocomplete: AutoComplete,
) -> Self::Output<AutoComplete> { ... }
fn cols(self, cols: u32) -> Self::Output<Cols> { ... }
fn dirname(
self,
dirname: impl Into<Cow<'static, str>>,
) -> Self::Output<Dirname> { ... }
fn disabled(self) -> Self::Output<Disabled> { ... }
fn with_disabled(self, disabled: bool) -> Self::Output<Disabled> { ... }
fn form(self, form: impl Into<Cow<'static, str>>) -> Self::Output<Form> { ... }
fn max_length(self, max_length: i32) -> Self::Output<MaxLength> { ... }
fn min_length(self, min_length: i32) -> Self::Output<MinLength> { ... }
fn name(self, name: impl Into<Cow<'static, str>>) -> Self::Output<Name> { ... }
fn placeholder(
self,
placeholder: impl Into<Cow<'static, str>>,
) -> Self::Output<Placeholder> { ... }
fn read_only(self) -> Self::Output<ReadOnly> { ... }
fn with_read_only(self, read_only: bool) -> Self::Output<ReadOnly> { ... }
fn required(self) -> Self::Output<Required> { ... }
fn with_required(self, required: bool) -> Self::Output<Required> { ... }
fn rows(self, rows: u32) -> Self::Output<Rows> { ... }
fn wrap(self, wrap: Wrap) -> Self::Output<Wrap> { ... }
fn wrap_hard(self) -> Self::Output<Wrap> { ... }
fn on_input<E>(
self,
event: impl FnOnce(InputEvent) -> E,
) -> Self::Output<OnInput>
where E: Serialize + 'static { ... }
fn on_change<E>(
self,
event: impl FnOnce(InputEvent) -> E,
) -> Self::Output<OnChange>
where E: Serialize + 'static { ... }
}Expand description
The textarea element represents a multiline plain text edit control for the element’s raw
value. The contents of the control represent the control’s default value.
Provided Methods
Sourcefn autocomplete(self, autocomplete: AutoComplete) -> Self::Output<AutoComplete>
fn autocomplete(self, autocomplete: AutoComplete) -> Self::Output<AutoComplete>
Hint for form autofill feature.
Sourcefn dirname(self, dirname: impl Into<Cow<'static, str>>) -> Self::Output<Dirname>
fn dirname(self, dirname: impl Into<Cow<'static, str>>) -> Self::Output<Dirname>
Name of form control to use for sending the element’s directionality in form submission.
Sourcefn with_disabled(self, disabled: bool) -> Self::Output<Disabled>
fn with_disabled(self, disabled: bool) -> Self::Output<Disabled>
Whether the form control is disabled.
Sourcefn form(self, form: impl Into<Cow<'static, str>>) -> Self::Output<Form>
fn form(self, form: impl Into<Cow<'static, str>>) -> Self::Output<Form>
Associates the element with a super::form element.
Sourcefn max_length(self, max_length: i32) -> Self::Output<MaxLength>
fn max_length(self, max_length: i32) -> Self::Output<MaxLength>
Maximum length of value.
Sourcefn min_length(self, min_length: i32) -> Self::Output<MinLength>
fn min_length(self, min_length: i32) -> Self::Output<MinLength>
Minimum length of value.
Sourcefn name(self, name: impl Into<Cow<'static, str>>) -> Self::Output<Name>
fn name(self, name: impl Into<Cow<'static, str>>) -> Self::Output<Name>
Name of the element to use for form submission.
Sourcefn placeholder(
self,
placeholder: impl Into<Cow<'static, str>>,
) -> Self::Output<Placeholder>
fn placeholder( self, placeholder: impl Into<Cow<'static, str>>, ) -> Self::Output<Placeholder>
User-visible label to be placed within the form control.
Sourcefn read_only(self) -> Self::Output<ReadOnly>
fn read_only(self) -> Self::Output<ReadOnly>
Whether to allow the value to be edited by the user.
Sourcefn with_read_only(self, read_only: bool) -> Self::Output<ReadOnly>
fn with_read_only(self, read_only: bool) -> Self::Output<ReadOnly>
Whether to allow the value to be edited by the user.
Sourcefn required(self) -> Self::Output<Required>
fn required(self) -> Self::Output<Required>
Whether the control is required for form submission.
Sourcefn with_required(self, required: bool) -> Self::Output<Required>
fn with_required(self, required: bool) -> Self::Output<Required>
Whether the control is required for form submission.
Sourcefn wrap(self, wrap: Wrap) -> Self::Output<Wrap>
fn wrap(self, wrap: Wrap) -> Self::Output<Wrap>
How the value of the form control is to be wrapped for form submission.
Sourcefn wrap_hard(self) -> Self::Output<Wrap>
fn wrap_hard(self) -> Self::Output<Wrap>
How the value of the form control is to be wrapped for form submission.
fn on_input<E>(
self,
event: impl FnOnce(InputEvent) -> E,
) -> Self::Output<OnInput>where
E: Serialize + 'static,
fn on_change<E>(
self,
event: impl FnOnce(InputEvent) -> E,
) -> Self::Output<OnChange>where
E: Serialize + 'static,
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.