pub fn meter(content: impl View) -> Html<Meter, (), impl View>Expand description
The meter element represents a scalar measurement within a known range, or a fractional value;
for example disk usage, the relevance of a query result, or the fraction of a voting population
to have selected a particular candidate.