pub trait Area: WithAttribute {
Show 14 methods
// Provided methods
fn alt(self, alt: impl Into<Cow<'static, str>>) -> Self::Output<Alt> { ... }
fn coords(
self,
coords: impl Into<Cow<'static, str>>,
) -> Self::Output<Coords> { ... }
fn shape(self, shape: Shape) -> Self::Output<Shape> { ... }
fn href(self, href: impl Into<Cow<'static, str>>) -> Self::Output<Href> { ... }
fn target(
self,
target: impl Into<Cow<'static, str>>,
) -> Self::Output<Target> { ... }
fn target_blank(self) -> Self::Output<Target> { ... }
fn target_parent(self) -> Self::Output<Target> { ... }
fn target_top(self) -> Self::Output<Target> { ... }
fn download_filename(
self,
download: impl Into<Cow<'static, str>>,
) -> Self::Output<Download> { ... }
fn download(self) -> Self::Output<Download> { ... }
fn ping(self, ping: impl Into<Cow<'static, str>>) -> Self::Output<Ping> { ... }
fn rel(self, rel: impl Into<SpaceSeparated<Rel>>) -> Self::Output<RelList> { ... }
fn append_rel(self, rel: Rel) -> Self::Output<RelList> { ... }
fn referrer_policy(
self,
referrer_policy: ReferrerPolicy,
) -> Self::Output<ReferrerPolicy> { ... }
}Expand description
The area element represents either a hyperlink with some text and a corresponding area on an
image map, or a dead area on an image map.
Provided Methods
Sourcefn alt(self, alt: impl Into<Cow<'static, str>>) -> Self::Output<Alt>
fn alt(self, alt: impl Into<Cow<'static, str>>) -> Self::Output<Alt>
Replacement text for use when images are not available.
Sourcefn coords(self, coords: impl Into<Cow<'static, str>>) -> Self::Output<Coords>
fn coords(self, coords: impl Into<Cow<'static, str>>) -> Self::Output<Coords>
Coordinates for the shape to be created in an image map.
Sourcefn shape(self, shape: Shape) -> Self::Output<Shape>
fn shape(self, shape: Shape) -> Self::Output<Shape>
The kind of shape to be created in an image map.
Sourcefn href(self, href: impl Into<Cow<'static, str>>) -> Self::Output<Href>
fn href(self, href: impl Into<Cow<'static, str>>) -> Self::Output<Href>
Address of the hyperlink.
Sourcefn target(self, target: impl Into<Cow<'static, str>>) -> Self::Output<Target>
fn target(self, target: impl Into<Cow<'static, str>>) -> Self::Output<Target>
The browsing context the link should be opened in.
Sourcefn target_blank(self) -> Self::Output<Target>
fn target_blank(self) -> Self::Output<Target>
Try to open the link in a new tab.
Sourcefn target_parent(self) -> Self::Output<Target>
fn target_parent(self) -> Self::Output<Target>
Open the link in the parent browsing context.
Sourcefn target_top(self) -> Self::Output<Target>
fn target_top(self) -> Self::Output<Target>
Open the link in the topmost browsing context.
Sourcefn download_filename(
self,
download: impl Into<Cow<'static, str>>,
) -> Self::Output<Download>
fn download_filename( self, download: impl Into<Cow<'static, str>>, ) -> Self::Output<Download>
Treat the linked URL as a download with the specified filename.
Sourcefn download(self) -> Self::Output<Download>
fn download(self) -> Self::Output<Download>
Treat the linked URL as a download and let the browser suggest a filename.
Sourcefn ping(self, ping: impl Into<Cow<'static, str>>) -> Self::Output<Ping>
fn ping(self, ping: impl Into<Cow<'static, str>>) -> Self::Output<Ping>
A space-separated list of URLs the browser will send POST requests (with the body PING) when the link is followed (typically used for tracking).
Sourcefn rel(self, rel: impl Into<SpaceSeparated<Rel>>) -> Self::Output<RelList>
fn rel(self, rel: impl Into<SpaceSeparated<Rel>>) -> Self::Output<RelList>
Relationship between the location in the document containing the hyperlink and the destination resource.
Sourcefn referrer_policy(
self,
referrer_policy: ReferrerPolicy,
) -> Self::Output<ReferrerPolicy>
fn referrer_policy( self, referrer_policy: ReferrerPolicy, ) -> Self::Output<ReferrerPolicy>
How much referrer information to send.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.