pub trait Global: WithAttribute {
Show 31 methods
// Provided methods
fn access_key(
self,
access_key: impl Into<Cow<'static, str>>,
) -> Self::Output<AccessKey> { ... }
fn auto_capitalize(
self,
auto_capitalize: AutoCapitalize,
) -> Self::Output<AutoCapitalize> { ... }
fn auto_focus(self) -> Self::Output<AutoFocus> { ... }
fn with_auto_focus(self, auto_focus: bool) -> Self::Output<AutoFocus> { ... }
fn content_editable(self) -> Self::Output<ContentEditable> { ... }
fn with_content_editable(
self,
content_editable: bool,
) -> Self::Output<ContentEditable> { ... }
fn dir(self, dir: Dir) -> Self::Output<Dir> { ... }
fn draggable(self) -> Self::Output<Draggable> { ... }
fn with_draggable(self, draggable: bool) -> Self::Output<Draggable> { ... }
fn enter_key_hint(
self,
enter_key_hint: EnterKeyHint,
) -> Self::Output<EnterKeyHint> { ... }
fn hidden(self, hidden: Hidden) -> Self::Output<Hidden> { ... }
fn inert(self) -> Self::Output<Inert> { ... }
fn with_inert(self, inert: bool) -> Self::Output<Inert> { ... }
fn input_mode(self, input_mode: InputMode) -> Self::Output<InputMode> { ... }
fn is(self, is: impl Into<Cow<'static, str>>) -> Self::Output<Is> { ... }
fn item_id(
self,
item_id: impl Into<Cow<'static, str>>,
) -> Self::Output<ItemId> { ... }
fn item_prop(
self,
item_prop: impl Into<Cow<'static, str>>,
) -> Self::Output<ItemProp> { ... }
fn item_ref(
self,
item_ref: impl Into<Cow<'static, str>>,
) -> Self::Output<ItemRef> { ... }
fn item_scope(self) -> Self::Output<ItemScope> { ... }
fn with_item_scope(self, item_scope: bool) -> Self::Output<ItemScope> { ... }
fn item_type(
self,
item_type: impl Into<Cow<'static, str>>,
) -> Self::Output<ItemType> { ... }
fn lang(self, lang: impl Into<Cow<'static, str>>) -> Self::Output<Lang> { ... }
fn nonce(self, nonce: impl Into<Cow<'static, str>>) -> Self::Output<Nonce> { ... }
fn popover(self) -> Self::Output<Popover> { ... }
fn with_popover(self, popover: bool) -> Self::Output<Popover> { ... }
fn slot(self, slot: impl Into<Cow<'static, str>>) -> Self::Output<Slot> { ... }
fn spellcheck(self, spellcheck: bool) -> Self::Output<Spellcheck> { ... }
fn style(self, style: impl Into<Cow<'static, str>>) -> Self::Output<Style> { ... }
fn tab_index(self, tab_index: TabIndex) -> Self::Output<TabIndex> { ... }
fn title(self, title: impl Into<Cow<'static, str>>) -> Self::Output<Title> { ... }
fn translate(self, translate: bool) -> Self::Output<Translate> { ... }
}Provided Methods
Sourcefn access_key(
self,
access_key: impl Into<Cow<'static, str>>,
) -> Self::Output<AccessKey>
fn access_key( self, access_key: impl Into<Cow<'static, str>>, ) -> Self::Output<AccessKey>
Used by the user agent as a guide for creating a keyboard shortcut that activates or focuses the element.
Sourcefn auto_capitalize(
self,
auto_capitalize: AutoCapitalize,
) -> Self::Output<AutoCapitalize>
fn auto_capitalize( self, auto_capitalize: AutoCapitalize, ) -> Self::Output<AutoCapitalize>
Hints the user-agent of how to automatically capitalize input (from non-physical
Sourcefn auto_focus(self) -> Self::Output<AutoFocus>
fn auto_focus(self) -> Self::Output<AutoFocus>
Indicate that the element is to be focused as soon as the page is loaded.
Sourcefn with_auto_focus(self, auto_focus: bool) -> Self::Output<AutoFocus>
fn with_auto_focus(self, auto_focus: bool) -> Self::Output<AutoFocus>
Indicate that the element is to be focused as soon as the page is loaded.
Sourcefn content_editable(self) -> Self::Output<ContentEditable>
fn content_editable(self) -> Self::Output<ContentEditable>
Indicating whether the element should be editable by the user.
Sourcefn with_content_editable(
self,
content_editable: bool,
) -> Self::Output<ContentEditable>
fn with_content_editable( self, content_editable: bool, ) -> Self::Output<ContentEditable>
Indicating whether the element should be editable by the user.
Sourcefn with_draggable(self, draggable: bool) -> Self::Output<Draggable>
fn with_draggable(self, draggable: bool) -> Self::Output<Draggable>
Indicate whether the element can be dragged.
Sourcefn enter_key_hint(
self,
enter_key_hint: EnterKeyHint,
) -> Self::Output<EnterKeyHint>
fn enter_key_hint( self, enter_key_hint: EnterKeyHint, ) -> Self::Output<EnterKeyHint>
Indicate the action label (or icon) to present for the enter key on virtual keyboards.
Hide the element (visually and from screen-readers).
Sourcefn inert(self) -> Self::Output<Inert>
fn inert(self) -> Self::Output<Inert>
Mark the element as not presently accessible (e.g. when overlayed by a loading state).
Sourcefn with_inert(self, inert: bool) -> Self::Output<Inert>
fn with_inert(self, inert: bool) -> Self::Output<Inert>
Mark the element as not presently accessible (e.g. when overlayed by a loading state).
Sourcefn input_mode(self, input_mode: InputMode) -> Self::Output<InputMode>
fn input_mode(self, input_mode: InputMode) -> Self::Output<InputMode>
Hint an input mechanism that would be most helpful for users entering content.
Sourcefn is(self, is: impl Into<Cow<'static, str>>) -> Self::Output<Is>
fn is(self, is: impl Into<Cow<'static, str>>) -> Self::Output<Is>
The element should behave like the defined custom element.
Sourcefn item_id(self, item_id: impl Into<Cow<'static, str>>) -> Self::Output<ItemId>
fn item_id(self, item_id: impl Into<Cow<'static, str>>) -> Self::Output<ItemId>
Unique, global identifier of the item (item_scope and item_type must also be defined).
Sourcefn item_prop(
self,
item_prop: impl Into<Cow<'static, str>>,
) -> Self::Output<ItemProp>
fn item_prop( self, item_prop: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemProp>
A microdata name-value pair (this is the name – either a string or URL; the element’s content is the value).
Sourcefn item_ref(
self,
item_ref: impl Into<Cow<'static, str>>,
) -> Self::Output<ItemRef>
fn item_ref( self, item_ref: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemRef>
List of element IDs elsewehre in the document with additional properties.
Sourcefn item_scope(self) -> Self::Output<ItemScope>
fn item_scope(self) -> Self::Output<ItemScope>
Create a new item by scoping the the descendent properties together (item_type must also
be defined).
Sourcefn with_item_scope(self, item_scope: bool) -> Self::Output<ItemScope>
fn with_item_scope(self, item_scope: bool) -> Self::Output<ItemScope>
Create a new item by scoping the the descendent properties together (item_type must also
be defined).
Sourcefn item_type(
self,
item_type: impl Into<Cow<'static, str>>,
) -> Self::Output<ItemType>
fn item_type( self, item_type: impl Into<Cow<'static, str>>, ) -> Self::Output<ItemType>
URL of the vocabulary that will be used to define item properties in the data structure.
Sourcefn lang(self, lang: impl Into<Cow<'static, str>>) -> Self::Output<Lang>
fn lang(self, lang: impl Into<Cow<'static, str>>) -> Self::Output<Lang>
Primary language of the element’s contents.
Sourcefn nonce(self, nonce: impl Into<Cow<'static, str>>) -> Self::Output<Nonce>
fn nonce(self, nonce: impl Into<Cow<'static, str>>) -> Self::Output<Nonce>
Cryptographic nonce (“number used once”) which can be used by Content Security Policy to determine whether or not a given fetch will be allowed to proceed.
Sourcefn popover(self) -> Self::Output<Popover>
fn popover(self) -> Self::Output<Popover>
Don’t render the element until it becomes shown, at which point it will be rendered on top of other page content.
Sourcefn with_popover(self, popover: bool) -> Self::Output<Popover>
fn with_popover(self, popover: bool) -> Self::Output<Popover>
Don’t render the element until it becomes shown, at which point it will be rendered on top of other page content.
Sourcefn slot(self, slot: impl Into<Cow<'static, str>>) -> Self::Output<Slot>
fn slot(self, slot: impl Into<Cow<'static, str>>) -> Self::Output<Slot>
The slot name this element is assigned to.
Sourcefn spellcheck(self, spellcheck: bool) -> Self::Output<Spellcheck>
fn spellcheck(self, spellcheck: bool) -> Self::Output<Spellcheck>
Explicitly enable or disable spelling and grammar checking for the element’s contents.
Sourcefn tab_index(self, tab_index: TabIndex) -> Self::Output<TabIndex>
fn tab_index(self, tab_index: TabIndex) -> Self::Output<TabIndex>
Specifify how and in which order the element can be focused.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.